@@ -75,7 +75,7 @@ def make_test_card() -> Table:
         "Text",
         RenderGroup(
             Text.from_markup(
-                """Word wrap text. Justify [green]left[/], [yellow]center[/], [blue]right[/] or [red]full[/].\n\n"""
+                """Word wrap text. Justify [green]left[/], [yellow]center[/], [blue]right[/] or [red]full[/].\n"""
             ),
             lorem_table,
         ),
@@ -177,5 +177,10 @@ if __name__ == "__main__":  # pragma: no cover
     start = process_time()
     console.print(test_card)
     taken = round((process_time() - start) * 1000.0, 1)
-    print(console.file.getvalue())  # type: ignore
+
+    text = console.file.getvalue()
+    # https://bugs.python.org/issue37871
+    for line in text.splitlines():
+        print(line)
+
     print(f"rendered in {taken}ms")
