@@ -1,47 +1,46 @@
-from collections.abc import Mapping, Sequence
-
-from dataclasses import dataclass, field, replace
-
-from functools import wraps
 import inspect
-
+import io
 import os
-
 import platform
-
 import shutil
 import sys
 import threading
+from abc import ABC, abstractmethod
+from collections.abc import Mapping, Sequence
+from dataclasses import dataclass, field, replace
+from functools import wraps
+from getpass import getpass
 from typing import (
+    IO,
+    TYPE_CHECKING,
     Any,
     Callable,
-    cast,
     Dict,
-    IO,
     Iterable,
     List,
-    Optional,
-    TYPE_CHECKING,
     NamedTuple,
+    Optional,
+    TextIO,
     Union,
+    cast,
 )
-from typing_extensions import Protocol, runtime_checkable, Literal
 
+from typing_extensions import Literal, Protocol, runtime_checkable
+
+from . import errors, themes
 from ._emoji_replace import _emoji_replace
-from .align import Align, AlignValues
-from .markup import render as render_markup
-from .measure import measure_renderables, Measurement
 from ._log_render import LogRender
-from . import errors
+from .align import Align, AlignValues
 from .color import ColorSystem
 from .control import Control
 from .highlighter import NullHighlighter, ReprHighlighter
+from .markup import render as render_markup
+from .measure import Measurement, measure_renderables
 from .pretty import Pretty
-from .style import Style
-from .tabulate import tabulate_mapping
-from . import themes
-from .terminal_theme import TerminalTheme, DEFAULT_TERMINAL_THEME
+from .scope import render_scope
 from .segment import Segment
+from .style import Style
+from .terminal_theme import DEFAULT_TERMINAL_THEME, TerminalTheme
 from .text import Text, TextType
 from .theme import Theme
 
@@ -75,18 +74,27 @@ body {{
 </html>
 """
 
+_TERM_COLORS = {"256color": ColorSystem.EIGHT_BIT, "16color": ColorSystem.STANDARD}
+
 
 @dataclass
 class ConsoleOptions:
     """Options for __rich_console__ method."""
 
     min_width: int
+    """Minimum width of renderable."""
     max_width: int
+    """Maximum width of renderable."""
     is_terminal: bool
+    """True if the target is a terminal, otherwise False."""
     encoding: str
+    """Encoding of terminal."""
     justify: Optional[JustifyMethod] = None
+    """Justify value override for renderable."""
     overflow: Optional[OverflowMethod] = None
+    """Overflow value override for renderable."""
     no_wrap: Optional[bool] = False
+    """"Disable wrapping for text."""
 
     def update(
         self,
@@ -191,7 +199,9 @@ class ConsoleDimensions(NamedTuple):
     """Size of the terminal."""
 
     width: int
+    """The width of the console in 'cells'."""
     height: int
+    """The height of the console in lines."""
 
 
 def _is_jupyter() -> bool:  # pragma: no cover
@@ -228,9 +238,10 @@ class ConsoleThreadLocals(threading.local):
     buffer_index: int = 0
 
 
-class RenderHook:
+class RenderHook(ABC):
     """Provides hooks in to the render process."""
 
+    @abstractmethod
     def process_renderables(
         self, renderables: List[ConsoleRenderable]
     ) -> List[ConsoleRenderable]:
@@ -244,7 +255,6 @@ class RenderHook:
         Returns:
             List[ConsoleRenderable]: A replacement list of renderables.
         """
-        return renderables
 
 
 _windows_console_features: Optional["WindowsConsoleFeatures"] = None
@@ -319,7 +329,11 @@ class Console:
         highlighter: Optional["HighlighterType"] = ReprHighlighter(),
         legacy_windows: bool = None,
         safe_box: bool = True,
+        _environ: Dict[str, str] = None,
     ):
+        # Copy of os.environ allows us to replace it for testing
+        self._environ = os.environ if _environ is None else _environ
+
         self.is_jupyter = force_jupyter or _is_jupyter()
         if self.is_jupyter:
             width = width or 93
@@ -351,7 +365,7 @@ class Console:
 
         self._lock = threading.RLock()
         self._log_render = LogRender(
-            show_time=log_time, show_path=log_path, time_format=log_time_format
+            show_time=log_time, show_path=log_path, time_format=log_time_format,
         )
         self.highlighter: HighlighterType = highlighter or _null_highlighter
         self.safe_box = safe_box
@@ -382,7 +396,7 @@ class Console:
         """Detect color system from env vars."""
         if self.is_jupyter:
             return ColorSystem.TRUECOLOR
-        if not self.is_terminal or "NO_COLOR" in os.environ:
+        if not self.is_terminal or "NO_COLOR" in self._environ or self.is_dumb_terminal:
             return None
         if WINDOWS:  # pragma: no cover
             if self.legacy_windows:  # pragma: no cover
@@ -394,12 +408,13 @@ class Console:
                 else ColorSystem.EIGHT_BIT
             )
         else:
-            color_term = os.environ.get("COLORTERM", "").strip().lower()
-            return (
-                ColorSystem.TRUECOLOR
-                if color_term in ("truecolor", "24bit")
-                else ColorSystem.EIGHT_BIT
-            )
+            color_term = self._environ.get("COLORTERM", "").strip().lower()
+            if color_term in ("truecolor", "24bit"):
+                return ColorSystem.TRUECOLOR
+            term = self._environ.get("TERM", "").strip().lower()
+            _term_name, _hyphen, colors = term.partition("-")
+            color_system = _TERM_COLORS.get(colors, ColorSystem.STANDARD)
+            return color_system
 
     def _enter_buffer(self) -> None:
         """Enter in to a buffer context, and buffer all output."""
@@ -459,7 +474,7 @@ class Console:
         """Check if the console is writing to a terminal.
 
         Returns:
-            bool: True if the console writting to a device capable of
+            bool: True if the console writing to a device capable of
             understanding terminal codes, otherwise False.
         """
         if self._force_terminal:
@@ -467,6 +482,20 @@ class Console:
         isatty = getattr(self.file, "isatty", None)
         return False if isatty is None else isatty()
 
+    @property
+    def is_dumb_terminal(self) -> bool:
+        """Detect dumb terminal.
+        
+        Returns:
+            bool: True if writing to a dumb terminal, otherwise False.
+        
+        """
+        is_dumb = "TERM" in self._environ and self._environ["TERM"].lower() in (
+            "dumb",
+            "unknown",
+        )
+        return self.is_terminal and is_dumb
+
     @property
     def options(self) -> ConsoleOptions:
         """Get default console options."""
@@ -484,10 +513,17 @@ class Console:
         Returns:
             ConsoleDimensions: A named tuple containing the dimensions.
         """
+
         if self._width is not None and self._height is not None:
             return ConsoleDimensions(self._width, self._height)
 
+        if self.is_terminal and self.is_dumb_terminal:
+            return ConsoleDimensions(80, 25)
+
         width, height = shutil.get_terminal_size()
+        # get_terminal_size can report 0, 0 if run from psuedo-terminal
+        width = width or 80
+        height = height or 25
         return ConsoleDimensions(
             (width - self.legacy_windows) if self._width is None else self._width,
             height if self._height is None else self._height,
@@ -533,7 +569,7 @@ class Console:
             self.control("\033[?25h" if show else "\033[?25l")
 
     def render(
-        self, renderable: RenderableType, options: ConsoleOptions
+        self, renderable: RenderableType, options: ConsoleOptions = None
     ) -> Iterable[Segment]:
         """Render an object in to an iterable of `Segment` instances.
 
@@ -543,16 +579,18 @@ class Console:
         Args:
             renderable (RenderableType): An object supporting the console protocol, or
                 an object that may be converted to a string.
-            options (ConsoleOptions): An options objects. Defaults to None.
+            options (ConsoleOptions, optional): An options object, or None to use self.options. Defaults to None.
 
         Returns:
             Iterable[Segment]: An iterable of segments that may be rendered.
         """
+
+        _options = options or self.options
         render_iterable: RenderResult
         if isinstance(renderable, ConsoleRenderable):
-            render_iterable = renderable.__rich_console__(self, options)
+            render_iterable = renderable.__rich_console__(self, _options)
         elif isinstance(renderable, str):
-            yield from self.render(self.render_str(renderable), options)
+            yield from self.render(self.render_str(renderable), _options)
             return
         else:
             raise errors.NotRenderableError(
@@ -570,12 +608,12 @@ class Console:
             if isinstance(render_output, Segment):
                 yield render_output
             else:
-                yield from self.render(render_output, options)
+                yield from self.render(render_output, _options)
 
     def render_lines(
         self,
         renderable: RenderableType,
-        options: Optional[ConsoleOptions],
+        options: Optional[ConsoleOptions] = None,
         *,
         style: Optional[Style] = None,
         pad: bool = True,
@@ -587,7 +625,7 @@ class Console:
 
         Args:
             renderables (Iterable[RenderableType]): Any object or objects renderable in the console.
-            options (Optional[ConsoleOptions]): Console options used to render with.
+            options (Optional[ConsoleOptions], optional): Console options, or None to use self.options. Default to ``None``.
             style (Style, optional): Optional style to apply to renderables. Defaults to ``None``.
             pad (bool, optional): Pad lines shorter than render width. Defaults to ``True``.
 
@@ -750,6 +788,7 @@ class Console:
                 append_text(_highlighter(str(renderable)))
 
         check_text()
+
         return renderables
 
     def rule(
@@ -776,9 +815,9 @@ class Console:
         Args:
             control_codes (str): Control codes, such as those that may move the cursor.
         """
-
-        self._buffer.append(Segment.control(str(control_codes)))
-        self._check_buffer()
+        if not self.is_dumb_terminal:
+            self._buffer.append(Segment.control(str(control_codes)))
+            self._check_buffer()
 
     def print(
         self,
@@ -918,7 +957,7 @@ class Console:
                     for key, value in caller.frame.f_locals.items()
                     if not key.startswith("__")
                 }
-                renderables.append(tabulate_mapping(locals_map, title="Locals"))
+                renderables.append(render_scope(locals_map, title="[i]locals"))
 
             renderables = [
                 self._log_render(
@@ -945,7 +984,13 @@ class Console:
                 else:
                     text = self._render_buffer()
                     if text:
-                        self.file.write(text)
+                        if WINDOWS:  # pragma: no cover
+                            # https://bugs.python.org/issue37871
+                            write = self.file.write
+                            for line in text.splitlines(True):
+                                write(line)
+                        else:
+                            self.file.write(text)
                         self.file.flush()
 
     def _render_buffer(self) -> str:
@@ -978,7 +1023,13 @@ class Console:
         return rendered
 
     def input(
-        self, prompt: TextType = "", *, markup: bool = True, emoji: bool = True
+        self,
+        prompt: TextType = "",
+        *,
+        markup: bool = True,
+        emoji: bool = True,
+        password: bool = False,
+        stream: TextIO = None,
     ) -> str:
         """Displays a prompt and waits for input from the user. The prompt may contain color / style. 
 
@@ -986,12 +1037,19 @@ class Console:
             prompt (Union[str, Text]): Text to render in the prompt.
             markup (bool, optional): Enable console markup (requires a str prompt). Defaults to True.
             emoji (bool, optional): Enable emoji (requires a str prompt). Defaults to True.
+            password: (bool, optional): Hide typed text. Defaults to False.
+            stream: (TextIO, optional): Optional file to read input from (rather than stdin). Defaults to None.
         
         Returns:
             str: Text read from stdin.
         """
-        self.print(prompt, markup=markup, emoji=emoji, end="")
-        result = input()
+        if prompt:
+            self.print(prompt, markup=markup, emoji=emoji, end="")
+        result = (
+            getpass("", stream=stream)
+            if password
+            else (stream.readline() if stream else input())
+        )
         return result
 
     def export_text(self, *, clear: bool = True, styles: bool = False) -> str:
@@ -999,7 +1057,7 @@ class Console:
 
         Args:
             clear (bool, optional): Set to ``True`` to clear the record buffer after exporting.
-            styles (bool, optional): If ``True``, ansi style codes will be included. ``False`` for plain text.
+            styles (bool, optional): If ``True``, ansi escape codes will be included. ``False`` for plain text.
                 Defaults to ``False``.
 
         Returns:
@@ -1017,7 +1075,11 @@ class Console:
                     for text, style, _ in self._record_buffer
                 )
             else:
-                text = "".join(text for text, _, _ in self._record_buffer)
+                text = "".join(
+                    segment.text
+                    for segment in self._record_buffer
+                    if not segment.is_control
+                )
             if clear:
                 del self._record_buffer[:]
         return text
@@ -1149,6 +1211,7 @@ class Console:
 
 if __name__ == "__main__":  # pragma: no cover
     console = Console()
+
     console.log(
         "JSONRPC [i]request[/i]",
         5,
