@@ -64,6 +64,15 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "repr.uuid": Style(color="bright_yellow", bold=False),
     "rule.line": Style(color="bright_green"),
     "rule.text": Style(),
+    "prompt": Style(),
+    "prompt.choices": Style(color="magenta", bold=True),
+    "prompt.default": Style(color="cyan", bold=True),
+    "prompt.invalid": Style(color="red"),
+    "prompt.invalid.choice": Style(color="red"),
+    "scope.border": Style(color="blue"),
+    "scope.key": Style(color="yellow", italic=True),
+    "scope.key.special": Style(color="yellow", italic=True, dim=True),
+    "scope.equals": Style(color="red"),
     "repr.path": Style(color="magenta"),
     "repr.filename": Style(color="bright_magenta"),
     "table.header": Style(bold=True),
