@@ -4,24 +4,32 @@ from logging import Handler, LogRecord
 from pathlib import Path
 from typing import ClassVar, List, Optional, Type
 
-from . import get_console
 from rich._log_render import LogRender
 from rich.console import Console
 from rich.highlighter import Highlighter, ReprHighlighter
 from rich.text import Text
 
+from . import get_console
+
 
 class RichHandler(Handler):
     """A logging handler that renders output with Rich. The time / level / message and file are displayed in columns.
-    The level is color coded, and the message is syntax highlighted.
-        
+    The level is color coded, and the message is syntax highlighted.            
+
+    Note:
+        Be careful when enabling console markup in log messages if you have configured logging for libraries not 
+        under your control. If a dependency writes messages containing square brackets, it may not produce the intended output.
+
     Args:
         level (int, optional): Log level. Defaults to logging.NOTSET.
         console (:class:`~rich.console.Console`, optional): Optional console instance to write logs.
             Default will use a global console instance writing to stdout.
+        show_time (bool, optional): Show a column for the time. Defaults to True.
+        show_level (bool, optional): Show a column for the level. Defaults to True.
         show_path (bool, optional): Show the path to the original log call. Defaults to True.
         enable_link_path (bool, optional): Enable terminal link of path column to file. Defaults to True.
         highlighter (Highlighter, optional): Highlighter to style log messages, or None to use ReprHighlighter. Defaults to None.
+        markup (bool, optional): Enable console markup in log messages. Defaults to False.
   
     """
 
@@ -42,15 +50,21 @@ class RichHandler(Handler):
         level: int = logging.NOTSET,
         console: Console = None,
         *,
+        show_time: bool = True,
+        show_level: bool = True,
         show_path: bool = True,
         enable_link_path: bool = True,
         highlighter: Highlighter = None,
+        markup: bool = False,
     ) -> None:
         super().__init__(level=level)
         self.console = console or get_console()
         self.highlighter = highlighter or self.HIGHLIGHTER_CLASS()
-        self._log_render = LogRender(show_level=True, show_path=show_path)
+        self._log_render = LogRender(
+            show_time=show_time, show_level=show_level, show_path=show_path
+        )
         self.enable_link_path = enable_link_path
+        self.markup = markup
 
     def emit(self, record: LogRecord) -> None:
         """Invoked by logging."""
@@ -63,7 +77,10 @@ class RichHandler(Handler):
         level = Text()
         level.append(record.levelname, log_style)
 
-        if getattr(record, "markup", False):
+        use_markup = (
+            getattr(record, "markup") if hasattr(record, "markup") else self.markup
+        )
+        if use_markup:
             message_text = Text.from_markup(message)
         else:
             message_text = Text(message)
@@ -93,7 +110,7 @@ if __name__ == "__main__":  # pragma: no cover
     FORMAT = "%(message)s"
     # FORMAT = "%(asctime)-15s - %(level) - %(message)s"
     logging.basicConfig(
-        level="NOTSET", format=FORMAT, datefmt="[%X]", handlers=[RichHandler()]
+        level="NOTSET", format=FORMAT, datefmt="[%X]", handlers=[RichHandler()],
     )
     log = logging.getLogger("rich")
 
@@ -117,6 +134,9 @@ if __name__ == "__main__":  # pragma: no cover
         },
         {"version": "1.1", "result": True, "error": None, "id": "194521489"},
     )
+    log.debug(
+        "Loading configuration file /adasd/asdasd/qeqwe/qwrqwrqwr/sdgsdgsdg/werwerwer/dfgerert/ertertert/ertetert/werwerwer"
+    )
     log.error("Unable to find 'pomelo' in database!")
     log.info("POST /jsonrpc/ 200 65532")
     log.info("POST /admin/ 401 42234")
