@@ -1,25 +1,23 @@
-from typing import Optional, Union
+from typing import Optional, TYPE_CHECKING
 
 from .box import get_safe_box, Box, SQUARE, ROUNDED
 
-from .console import (
-    Console,
-    ConsoleOptions,
-    RenderableType,
-    RenderResult,
-    Measurement,
-)
+from .align import AlignValues
 from .jupyter import JupyterMixin
+from .measure import Measurement
 from .padding import Padding, PaddingDimensions
-from .style import Style, StyleType
-from .text import Text
+from .style import StyleType
+from .text import Text, TextType
 from .segment import Segment
 
+if TYPE_CHECKING:
+    from .console import Console, ConsoleOptions, RenderableType, RenderResult
+
 
 class Panel(JupyterMixin):
     """A console renderable that draws a border around its contents.
     
-    Example::
+    Example:
         >>> console.print(Panel("Hello, World!"))
 
     Args:
@@ -37,9 +35,11 @@ class Panel(JupyterMixin):
 
     def __init__(
         self,
-        renderable: RenderableType,
+        renderable: "RenderableType",
         box: Box = ROUNDED,
         *,
+        title: TextType = None,
+        title_align: AlignValues = "center",
         safe_box: Optional[bool] = None,
         expand: bool = True,
         style: StyleType = "none",
@@ -49,6 +49,8 @@ class Panel(JupyterMixin):
     ) -> None:
         self.renderable = renderable
         self.box = box
+        self.title = title
+        self.title_align = title_align
         self.safe_box = safe_box
         self.expand = expand
         self.style = style
@@ -59,9 +61,11 @@ class Panel(JupyterMixin):
     @classmethod
     def fit(
         cls,
-        renderable: RenderableType,
+        renderable: "RenderableType",
         box: Box = ROUNDED,
         *,
+        title: TextType = None,
+        title_align: AlignValues = "center",
         safe_box: Optional[bool] = None,
         style: StyleType = "none",
         border_style: StyleType = "none",
@@ -72,6 +76,8 @@ class Panel(JupyterMixin):
         return cls(
             renderable,
             box,
+            title=title,
+            title_align=title_align,
             safe_box=safe_box,
             style=style,
             border_style=border_style,
@@ -81,8 +87,8 @@ class Panel(JupyterMixin):
         )
 
     def __rich_console__(
-        self, console: Console, options: ConsoleOptions
-    ) -> RenderResult:
+        self, console: "Console", options: "ConsoleOptions"
+    ) -> "RenderResult":
         _padding = Padding.unpack(self.padding)
         renderable = (
             Padding(self.renderable, _padding) if any(_padding) else self.renderable
@@ -108,7 +114,26 @@ class Panel(JupyterMixin):
         line_start = Segment(box.mid_left, border_style)
         line_end = Segment(f"{box.mid_right}", border_style)
         new_line = Segment.line()
-        yield Segment(box.get_top([width - 2]), border_style)
+        if self.title is None:
+            yield Segment(box.get_top([width - 2]), border_style)
+        else:
+            title_text = (
+                Text.from_markup(self.title)
+                if isinstance(self.title, str)
+                else self.title.copy()
+            )
+
+            title_text.style = border_style
+            title_text.end = ""
+            title_text.plain = title_text.plain.replace("\n", " ")
+            title_text = title_text.tabs_to_spaces()
+            title_text.pad(1)
+            title_text.align(self.title_align, width - 4, character=box.top)
+
+            yield Segment(box.top_left + box.top, border_style)
+            yield from console.render(title_text)
+            yield Segment(box.top + box.top_right, border_style)
+
         yield new_line
         for line in lines:
             yield line_start
@@ -118,7 +143,7 @@ class Panel(JupyterMixin):
         yield Segment(box.get_bottom([width - 2]), border_style)
         yield new_line
 
-    def __rich_measure__(self, console: "Console", max_width: int) -> Measurement:
+    def __rich_measure__(self, console: "Console", max_width: int) -> "Measurement":
         width = Measurement.get(console, self.renderable, max_width - 2).maximum + 2
         return Measurement(width, width)
 
@@ -129,7 +154,7 @@ if __name__ == "__main__":  # pragma: no cover
     c = Console()
 
     from .padding import Padding
-    from .box import ROUNDED
+    from .box import ROUNDED, DOUBLE
 
     p = Panel(
         Panel.fit(
@@ -138,7 +163,8 @@ if __name__ == "__main__":  # pragma: no cover
             safe_box=True,
             style="on red",
         ),
-        border_style="on blue",
+        title="[b]Hello, World",
+        box=DOUBLE,
     )
 
     print(p)
