@@ -1,45 +1,45 @@
+import io
+import sys
 from abc import ABC, abstractmethod
 from collections import deque
 from collections.abc import Sized
 from dataclasses import dataclass, field
 from datetime import timedelta
-import io
 from math import ceil
-import sys
-from time import monotonic
 from threading import Event, RLock, Thread
+from time import monotonic, perf_counter
 from typing import (
+    IO,
+    TYPE_CHECKING,
     Any,
     Callable,
     Deque,
     Dict,
     Iterable,
-    IO,
+    Iterator,
     List,
-    Optional,
     NamedTuple,
+    NewType,
+    Optional,
     Sequence,
     Tuple,
     TypeVar,
-    TYPE_CHECKING,
-    NewType,
     Union,
 )
 
-from . import get_console
+from . import filesize, get_console
 from .bar import Bar
 from .console import (
     Console,
     ConsoleRenderable,
     JustifyMethod,
+    RenderableType,
     RenderGroup,
     RenderHook,
-    RenderableType,
 )
 from .control import Control
 from .highlighter import Highlighter
 from .jupyter import JupyterMixin
-from . import filesize
 from .live_render import LiveRender
 from .style import StyleType
 from .table import Table
@@ -53,6 +53,40 @@ ProgressType = TypeVar("ProgressType")
 GetTimeCallable = Callable[[], float]
 
 
+class _TrackThread(Thread):
+    """A thread to periodically update progress."""
+
+    def __init__(self, progress: "Progress", task_id: "TaskID", update_period: float):
+        self.progress = progress
+        self.task_id = task_id
+        self.update_period = update_period
+        self.done = Event()
+
+        self.completed = 0
+        super().__init__()
+
+    def run(self) -> None:
+        task_id = self.task_id
+        advance = self.progress.advance
+        update_period = self.update_period
+        last_completed = 0
+        wait = self.done.wait
+        while not wait(update_period):
+            completed = self.completed
+            if last_completed != completed:
+                advance(task_id, completed - last_completed)
+                last_completed = completed
+        self.progress.update(self.task_id, completed=self.completed, refresh=True)
+
+    def __enter__(self) -> "_TrackThread":
+        self.start()
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
+        self.done.set()
+        self.join()
+
+
 def track(
     sequence: Union[Sequence[ProgressType], Iterable[ProgressType]],
     description="Working...",
@@ -66,8 +100,9 @@ def track(
     complete_style: StyleType = "bar.complete",
     finished_style: StyleType = "bar.finished",
     pulse_style: StyleType = "bar.pulse",
+    update_period: float = 0.1,
 ) -> Iterable[ProgressType]:
-    """Track progress of processing a sequence.
+    """Track progress by iterating over a sequence.
     
     Args:
         sequence (Iterable[ProgressType]): A sequence (must support "len") you wish to iterate over.
@@ -80,7 +115,8 @@ def track(
         style (StyleType, optional): Style for the bar background. Defaults to "bar.back".
         complete_style (StyleType, optional): Style for the completed bar. Defaults to "bar.complete".
         finished_style (StyleType, optional): Style for a finished bar. Defaults to "bar.done".   
-        pulse_style (StyleType, optional): Style for pulsing bars. Defaults to "bar.pulse".     
+        pulse_style (StyleType, optional): Style for pulsing bars. Defaults to "bar.pulse". 
+        update_period (float, optional): Minimum time (in seconds) between calls to update(). Defaults to 0.1.
     Returns:
         Iterable[ProgressType]: An iterable of the values in the sequence.
     
@@ -110,22 +146,9 @@ def track(
         refresh_per_second=refresh_per_second,
     )
 
-    task_total = total
-    if task_total is None:
-        if isinstance(sequence, Sized):
-            task_total = len(sequence)
-        else:
-            raise ValueError(
-                f"unable to get size of {sequence!r}, please specify 'total'"
-            )
-
-    task_id = progress.add_task(description, total=task_total)
-    with progress:
-        for completed, value in enumerate(sequence, 1):
-            yield value
-            progress.update(task_id, completed=completed)
-            if not progress.auto_refresh:
-                progress.refresh()
+    yield from progress.track(
+        sequence, total=total, description=description, update_period=update_period
+    )
 
 
 class ProgressColumn(ABC):
@@ -304,7 +327,9 @@ class ProgressSample(NamedTuple):
     """Sample of progress for a given time."""
 
     timestamp: float
+    """Timestamp of sample."""
     completed: float
+    """Number of steps completed."""
 
 
 @dataclass
@@ -334,7 +359,7 @@ class Task:
     """bool: Indicates if this task is visible in the progress display."""
 
     fields: Dict[str, Any] = field(default_factory=dict)
-    """Arbitrary fields passed in via Progress.update."""
+    """dict: Arbitrary fields passed in via Progress.update."""
 
     start_time: Optional[float] = field(default=None, init=False, repr=False)
     """Optional[float]: Time this task was started, or None if not started."""
@@ -347,7 +372,7 @@ class Task:
     )
 
     def get_time(self) -> float:
-        """Get the current time, in seconds."""
+        """float: Get the current time, in seconds."""
         return self._get_time()  # type: ignore
 
     @property
@@ -376,7 +401,7 @@ class Task:
 
     @property
     def percentage(self) -> float:
-        """float: Get progress of task as a percantage."""
+        """float: Get progress of task as a percentage."""
         if not self.total:
             return 0.0
         completed = (self.completed / self.total) * 100.0
@@ -388,13 +413,15 @@ class Task:
         """Optional[float]: Get the estimated speed in steps per second."""
         if self.start_time is None:
             return None
-        progress = list(self._progress)
+        progress = self._progress
         if not progress:
             return None
         total_time = progress[-1].timestamp - progress[0].timestamp
         if total_time == 0:
             return None
-        total_completed = sum(sample.completed for sample in progress[1:])
+        iter_progress = iter(progress)
+        next(iter_progress)
+        total_completed = sum(sample.completed for sample in iter_progress)
         speed = total_completed / total_time
         return speed
 
@@ -592,7 +619,7 @@ class Progress(JupyterMixin, RenderHook):
             self._refresh_thread = None
         if self.transient:
             self.console.control(self._live_render.restore_cursor())
-        if self.ipy_widget is not None and self.transient:
+        if self.ipy_widget is not None and self.transient:  # pragma: no cover
             self.ipy_widget.clear_output()
             self.ipy_widget.close()
 
@@ -609,14 +636,16 @@ class Progress(JupyterMixin, RenderHook):
         total: int = None,
         task_id: Optional[TaskID] = None,
         description="Working...",
+        update_period: float = 0.1,
     ) -> Iterable[ProgressType]:
-        """[summary]
+        """Track progress by iterating over a sequence.
         
         Args:
             sequence (Sequence[ProgressType]): A sequence of values you want to iterate over and track progress.
             total: (int, optional): Total number of steps. Default is len(sequence).
             task_id: (TaskID): Task to track. Default is new task.
             description: (str, optional): Description of task, if new task is created.
+            update_period (float, optional): Minimum time (in seconds) between calls to update(). Defaults to 0.1.
         
         Returns:
             Iterable[ProgressType]: An iterable of values taken from the provided sequence.
@@ -636,9 +665,18 @@ class Progress(JupyterMixin, RenderHook):
         else:
             self.update(task_id, total=task_total)
         with self:
-            for completed, value in enumerate(sequence, 1):
-                yield value
-                self.update(task_id, completed=completed)
+            if self.auto_refresh:
+                with _TrackThread(self, task_id, update_period) as track_thread:
+                    for value in sequence:
+                        yield value
+                        track_thread.completed += 1
+            else:
+                advance = self.advance
+                refresh = self.refresh
+                for value in sequence:
+                    yield value
+                    advance(task_id, 1)
+                    refresh()
 
     def start_task(self, task_id: TaskID) -> None:
         """Start a task.
@@ -676,6 +714,7 @@ class Progress(JupyterMixin, RenderHook):
         total: float = None,
         completed: float = None,
         advance: float = None,
+        description: str = None,
         visible: bool = None,
         refresh: bool = False,
         **fields: Any,
@@ -687,11 +726,11 @@ class Progress(JupyterMixin, RenderHook):
             total (float, optional): Updates task.total if not None.
             completed (float, optional): Updates task.completed if not None.
             advance (float, optional): Add a value to task.completed if not None.
+            description (str, optional): Change task description if not None.
             visible (bool, optional): Set visible flag if not None.
             refresh (bool): Force a refresh of progress information. Default is False.
             **fields (Any): Additional data fields required for rendering.
         """
-        current_time = self.get_time()
         with self._lock:
             task = self._tasks[task_id]
             completed_start = task.completed
@@ -702,19 +741,26 @@ class Progress(JupyterMixin, RenderHook):
                 task.completed += advance
             if completed is not None:
                 task.completed = completed
+            if description is not None:
+                task.description = description
             if visible is not None:
                 task.visible = visible
             task.fields.update(fields)
-
             update_completed = task.completed - completed_start
+
+            if refresh:
+                self.refresh()
+
+            current_time = self.get_time()
             old_sample_time = current_time - self.speed_estimate_period
             _progress = task._progress
 
+            popleft = _progress.popleft
             while _progress and _progress[0].timestamp < old_sample_time:
-                _progress.popleft()
-            task._progress.append(ProgressSample(current_time, update_completed))
-            if refresh:
-                self.refresh()
+                popleft()
+            while len(_progress) > 20:
+                popleft()
+            _progress.append(ProgressSample(current_time, update_completed))
 
     def advance(self, task_id: TaskID, advance: float = 1) -> None:
         """Advance task by a number of steps.
@@ -723,7 +769,21 @@ class Progress(JupyterMixin, RenderHook):
             task_id (TaskID): ID of task.
             advance (float): Number of steps to advance. Default is 1.
         """
-        self.update(task_id, advance=advance)
+        current_time = self.get_time()
+        with self._lock:
+            task = self._tasks[task_id]
+            completed_start = task.completed
+            task.completed += advance
+            update_completed = task.completed - completed_start
+            old_sample_time = current_time - self.speed_estimate_period
+            _progress = task._progress
+
+            popleft = _progress.popleft
+            while _progress and _progress[0].timestamp < old_sample_time:
+                popleft()
+            while len(_progress) > 10:
+                popleft()
+            _progress.append(ProgressSample(current_time, update_completed))
 
     def refresh(self) -> None:
         """Refresh (render) the progress information."""
@@ -745,7 +805,7 @@ class Progress(JupyterMixin, RenderHook):
                         self.ipy_widget.clear_output(wait=True)
                         self.console.print(self.get_renderable())
 
-        elif self.console.is_terminal:
+        elif self.console.is_terminal and not self.console.is_dumb_terminal:
             with self._lock:
                 self._live_render.set_renderable(self.get_renderable())
                 with self.console:
@@ -903,9 +963,9 @@ if __name__ == "__main__":  # pragma: no coverage
     console = Console()
     with Progress(console=console, transient=True) as progress:
 
-        task1 = progress.add_task(" [red]Downloading", total=1000)
-        task2 = progress.add_task(" [green]Processing", total=1000)
-        task3 = progress.add_task(" [yellow]Thinking", total=1000, start=False)
+        task1 = progress.add_task("[red]Downloading", total=1000)
+        task2 = progress.add_task("[green]Processing", total=1000)
+        task3 = progress.add_task("[yellow]Thinking", total=1000, start=False)
 
         while not progress.finished:
             progress.update(task1, advance=0.5)
@@ -913,4 +973,3 @@ if __name__ == "__main__":  # pragma: no coverage
             time.sleep(0.01)
             if random.randint(0, 100) < 1:
                 progress.log(next(examples))
-
