@@ -15,13 +15,14 @@ from typing import (
 )
 
 from ._loop import loop_last
+from ._pick import pick_bool
 from ._wrap import divide_line
+from .align import AlignValues
 from .cells import cell_len, set_cell_size
 from .containers import Lines
 from .control import strip_control_codes
 from .jupyter import JupyterMixin
 from .measure import Measurement
-from ._pick import pick_bool
 from .segment import Segment
 from .style import Style, StyleType
 
@@ -48,8 +49,11 @@ class Span(NamedTuple):
     """A marked up region in some text."""
 
     start: int
+    """Span start index."""
     end: int
+    """Span end index."""
     style: Union[str, Style]
+    """Style associated with the span."""
 
     def __repr__(self) -> str:
         return f"Span({self.start}, {self.end}, {str(self.style)!r})"
@@ -105,8 +109,10 @@ class Text(JupyterMixin):
             style (Union[str, Style], optional): Base style for text. Defaults to "".
             justify (str, optional): Justify method: "left", "center", "full", "right". Defaults to None.
             overflow (str, optional): Overflow method: "crop", "fold", "ellipsis". Defaults to None. 
+            no_wrap (bool, optional): Disable text wrapping, or None for default. Defaults to None.
             end (str, optional): Character to end text with. Defaults to "\n".
             tab_size (int): Number of spaces per tab, or ``None`` to use ``console.tab_size``. Defaults to 8.
+            spans (List[Span], optional). A list of predefined style spans. Defaults to None.
     """
 
     __slots__ = [
@@ -202,6 +208,31 @@ class Text(JupyterMixin):
         rendered_text.overflow = overflow
         return rendered_text
 
+    @classmethod
+    def styled(
+        cls,
+        text: str,
+        style: StyleType = "",
+        *,
+        justify: "JustifyMethod" = None,
+        overflow: "OverflowMethod" = None,
+    ) -> "Text":
+        """Construct a Text instance with a pre-applied styled. A style applied in this way won't be used
+        to pad the text when it is justified.
+
+        Args:
+            text (str): A string containing console markup.
+            style (Union[str, Style]): Style to apply to the text. Defaults to "".
+            justify (str, optional): Justify method: "left", "center", "full", "right". Defaults to None.
+            overflow (str, optional): Overflow method: "crop", "fold", "ellipsis". Defaults to None. 
+        
+        Returns:
+            Text: A text instance with a style applied to the entire string.
+        """
+        styled_text = cls(text, justify=justify, overflow=overflow)
+        styled_text.stylize(style)
+        return styled_text
+
     @classmethod
     def assemble(
         cls,
@@ -212,14 +243,14 @@ class Text(JupyterMixin):
         end: str = "\n",
         tab_size: int = 8,
     ) -> "Text":
-        """Construct a text instance by combining a sequence of strings with optional styles.
+        r"""Construct a text instance by combining a sequence of strings with optional styles.
         The positional arguments should be either strings, or a tuple of string + style.        
 
         Args:            
             style (Union[str, Style], optional): Base style for text. Defaults to "".
             justify (str, optional): Justify method: "left", "center", "full", "right". Defaults to None.
             overflow (str, optional): Overflow method: "crop", "fold", "ellipsis". Defaults to None. 
-            end (str, optional): Character to end text with. Defaults to "\n".
+            end (str, optional): Character to end text with. Defaults to "\\n".
             tab_size (int): Number of spaces per tab, or ``None`` to use ``console.tab_size``. Defaults to 8.
 
         Returns:
@@ -229,8 +260,9 @@ class Text(JupyterMixin):
             style=style, justify=justify, overflow=overflow, end=end, tab_size=tab_size
         )
         append = text.append
+        _Text = Text
         for part in parts:
-            if isinstance(part, (Text, str)):
+            if isinstance(part, (_Text, str)):
                 append(part)
             else:
                 append(*part)
@@ -289,31 +321,28 @@ class Text(JupyterMixin):
         copy_self._spans[:] = self._spans
         return copy_self
 
-    def stylize(self, start: int, end: int, style: Union[str, Style]) -> None:
-        """Apply a style to a portion of the text.
-        
-        Args:
-            start (int): Start offset.
-            end (int): End offset.
+    def stylize(
+        self, style: Union[str, Style], start: int = 0, end: Optional[int] = None
+    ) -> None:
+        """Apply a style to the text, or a portion of the text.        
+
+        Args:            
             style (Union[str, Style]): Style instance or style definition to apply.
+            start (int): Start offset (negative indexing is supported). Defaults to 0.
+            end (Optional[int], optional): End offset (negative indexing is supported), or None for end of text. Defaults to None.
 
         """
         length = len(self)
-        if end < 0 or start >= length:
-            # span not in range
+        if start < 0:
+            start = length + start
+        if end is None:
+            end = length
+        if end < 0:
+            end = length + end
+        if start >= length or end <= start:
+            # Span not in text or not valid
             return
-        self._spans.append(Span(max(0, start), min(length + 1, end), style))
-
-    def stylize_all(self, style: Union[str, Style]) -> None:
-        """Apply a style to all the text.
-
-        Args:
-            start (int): Start offset.
-            end (int): End offset.
-            style (Union[str, Style]): Style instance or style definition to apply.
-
-        """
-        self._spans.append(Span(0, len(self), style))
+        self._spans.append(Span(start, min(length, end), style))
 
     def get_style_at_offset(self, console: "Console", offset: int) -> Style:
         """Get the style of a character at give offset.
@@ -385,6 +414,7 @@ class Text(JupyterMixin):
         Args:
             words (Iterable[str]): Worlds to highlight.
             style (Union[str, Style]): Style to apply.
+            case_sensitive (bool, optional): Enable case sensitive matchings. Defaults to True.
         
         Returns:
             int: Number of words highlighted.
@@ -402,10 +432,10 @@ class Text(JupyterMixin):
         return count
 
     def rstrip(self) -> None:
-        """Trip whitespace from end of text."""
+        """Strip whitespace from end of text."""
         self.plain = self.plain.rstrip()
 
-    def rstrip_end(self, size: int):
+    def rstrip_end(self, size: int) -> None:
         """Remove whitespace beyond a certain width at the end of the text.
 
         Args:
@@ -613,6 +643,22 @@ class Text(JupyterMixin):
                 append(span)
         self._spans[:] = spans
 
+    def pad(self, count: int, character: str = " ") -> None:
+        """Pad left and right with a given number of characters.
+
+        Args:
+            count (int): Width of padding.
+        """
+        assert len(character) == 1, "Character must be a string of length 1"
+        if count:
+            pad_characters = character * count
+            self.plain = f"{pad_characters}{self.plain}{pad_characters}"
+            _Span = Span
+            self._spans[:] = [
+                _Span(start + count, end + count, style)
+                for start, end, style in self._spans
+            ]
+
     def pad_left(self, count: int, character: str = " ") -> None:
         """Pad the left with a given character.
         
@@ -623,7 +669,11 @@ class Text(JupyterMixin):
         assert len(character) == 1, "Character must be a string of length 1"
         if count:
             self.plain = f"{character * count}{self.plain}"
-            self._spans[:] = [span.move(count) for span in self._spans]
+            _Span = Span
+            self._spans[:] = [
+                _Span(start + count, end + count, style)
+                for start, end, style in self._spans
+            ]
 
     def pad_right(self, count: int, character: str = " ") -> None:
         """Pad the right with a given character.
@@ -636,6 +686,26 @@ class Text(JupyterMixin):
         if count:
             self.plain = f"{self.plain}{character * count}"
 
+    def align(self, align: AlignValues, width: int, character: str = " ") -> None:
+        """Align text to a given width.
+
+        Args:
+            align (AlignValues): One of "left", "center", or "right".
+            width (int): Desired width.
+            character (str, optional): Character to pad with. Defaults to " ".
+        """
+        self.truncate(width)
+        excess_space = width - cell_len(self.plain)
+        if excess_space:
+            if align == "left":
+                self.pad_right(excess_space, character)
+            elif align == "center":
+                left = excess_space // 2
+                self.pad_left(left, character)
+                self.pad_right(excess_space - left, character)
+            else:
+                self.pad_left(excess_space, character)
+
     def append(
         self, text: Union["Text", str], style: Union[str, "Style"] = None
     ) -> "Text":
@@ -688,11 +758,19 @@ class Text(JupyterMixin):
         """
         self._spans.extend(text._spans)
 
-    def split(self, separator="\n", *, include_separator: bool = False) -> Lines:
+    def split(
+        self,
+        separator="\n",
+        *,
+        include_separator: bool = False,
+        allow_blank: bool = False,
+    ) -> Lines:
         r"""Split rich text in to lines, preserving styles.
         
         Args:
             separator (str, optional): String to split on. Defaults to "\n".
+            include_separator (bool, optional): Include the separator in the lines. Defaults to False.
+            allow_blank (bool, optional): Return a blank line if the text ends with a separator. Defaults to False.
         
         Returns:
             List[RichText]: A list of rich text, one per line of the original.
@@ -702,7 +780,7 @@ class Text(JupyterMixin):
         text = self.plain
         if separator not in text:
             return Lines([self.copy()])
-        if text.endswith(separator):
+        if not allow_blank and text.endswith(separator):
             text = text[: -len(separator)]
         offsets: List[int] = []
         append = offsets.append
@@ -816,8 +894,8 @@ class Text(JupyterMixin):
             "OverflowMethod", overflow or self.overflow or DEFAULT_OVERFLOW
         )
         no_wrap = pick_bool(no_wrap, self.no_wrap, False)
-        lines: Lines = Lines()
-        for line in self.split():
+        lines = Lines()
+        for line in self.split(allow_blank=True):
             if "\t" in line:
                 line = line.tabs_to_spaces(tab_size)
             if no_wrap:
@@ -834,7 +912,6 @@ class Text(JupyterMixin):
             for line in new_lines:
                 line.truncate(width, overflow=wrap_overflow)
             lines.extend(new_lines)
-
         return lines
 
     def fit(self, width: int) -> Lines:
@@ -854,7 +931,7 @@ class Text(JupyterMixin):
         return lines
 
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     from rich.console import Console
 
     console = Console()
